import { useRef, useState, useEffect } from 'react';
import { connect, history } from '@umijs/max';
import type { ActionType, ProFormInstance } from '@ant-design/pro-components';
import {
    ProTable, TableDropdown
} from '@ant-design/pro-components';
import { Button, Image, ConfigProvider, Select } from 'antd';
import { GetAdvertareaList} from '@/apis/api';

const PagesMainAdvertisementListTable: React.FC = ({ dispatch, openModel, getId }: any) => {
    const actionRef = useRef<ActionType>();
    const [list, setList] = useState<object[]>([])
    const [total, setTotal] = useState<number>(0)
    const [page, setPage] = useState<number>(1)
    const [pageSize, setPageSize] = useState<number>(10)

    const setId = (id: number) => {
        getId(id)
    }

    useEffect(() => {
        if (!openModel.openModal) {
            actionRef.current.reload();
        }
    }, [openModel.openModal])

    return (
        <>
            <ConfigProvider
                theme={{
                    token: {
                        colorPrimary: '#4FBE70',
                        colorLink: '#4FBE70',
                    }
                }}
            >
                <ProTable
                    size='small'
                    bordered={true}
                    scroll={{ x: 1300 }}
                    actionRef={actionRef}
                    dataSource={list}
                    columns={[ {
                        title: 'ID',
                        dataIndex: 'id',
                        width: 100,
                        search: false,
                    },
                        {
                            title: '广告位置',
                            dataIndex: 'name',
                            width: 240
                        },
                        {
                            title: '广告位置代码',
                            dataIndex: 'code',
                            search: false
                        },
                        {
                            title: '限制显示广告数',
                            dataIndex: 'ad_num',
                            search: false
                        },
                        {
                            title: '显示列数',
                            dataIndex: 'cols',
                            search: false
                        },{
                            title: '广告显示宽度',
                            dataIndex: 'width',
                            search: false
                        },{
                            title: '广告显示高度',
                            dataIndex: 'height',
                            search: false
                        },{
                            title: '列间距',
                            dataIndex: 'col_padding',
                            search: false
                        },{
                            title: '行间距',
                            dataIndex: 'row_padding',
                            search: false
                        },
                        {
                            title: '操作',
                            width: 300,
                            key: 'option',
                            valueType: 'option',
                            fixed: 'right',
                            render: (_, record, action) => [
                                <Button key='1' type='link' onClick={() => {
                                    setId(record.id)
                                    dispatch({ type: 'openModel/getOpenModal', payload: true })
                                }}>编辑</Button>,
                                <Button key='2' type='link' onClick={() => {

                                }}>删除</Button>
                            ],
                        },
                    ]}
                    rowKey="id"
                    pagination={{
                        current: page,
                        pageSize: pageSize,
                        showSizeChanger: true,
                        total: total,
                        pageSizeOptions: [9, 18, 27, 99],
                        onChange(page, pageSize) {
                            setPage(page)
                            setPageSize(pageSize)
                        },
                        onShowSizeChange(current, size) {
                            setPage(current)
                            setPageSize(size)
                        }
                    }}
                    request={async (params = {} as Record<string, any>) =>
                        GetAdvertareaList({
                            page: page,
                            pagesize: pageSize,
                            sort: 'id',
                            sortby: 'desc',
                            keyword: params.name,
                      
                        }).then(res => {
                            setList(res.data.advertareas)
                            setTotal(res.data.total)
                        })
                    }
                    headerTitle="广告位置列表"
                    toolBarRender={() => [
                        <Button type="primary" onClick={() => {
                            dispatch({ type: 'openModel/getOpenModal', payload: true })
                        }}>
                            添加广告位置
                        </Button>
                    ]}
                />
            </ConfigProvider>
        </>
    );
};


export default connect(({ openModel }: any) => ({
    openModel
}))(PagesMainAdvertisementListTable);
