import { useRef, useState, useEffect } from 'react';
import { connect, history } from '@umijs/max';
import type { ActionType, ProFormInstance } from '@ant-design/pro-components';
import {
    ProTable, ProFormSelect
} from '@ant-design/pro-components';
import { Button, Popconfirm, ConfigProvider, Tag,message  } from 'antd';
import { GetAdvertscheduleList, getCompanyList, GetAdvertareaList, PostAdvertscheduleDel} from '@/apis/api';
const selectfieldNames = { label: 'full_name', value: 'id' };
const selectfieldAreaNames = { label: 'name', value: 'id' };

const PagesMainAdvertisementPutinTable: React.FC = ({ dispatch, openModel, getId }: any) => {
    const actionRef = useRef<ActionType>();
    const [list, setList] = useState<object[]>([])
    const [total, setTotal] = useState<number>(0)
    const [page, setPage] = useState<number>(1)
    const [pageSize, setPageSize] = useState<number>(10)

    const setId = (id: number) => {
        getId(id)
    }

    useEffect(() => {
        if (!openModel.openModal) {
            actionRef.current.reload();
        }
    }, [openModel.openModal])

    return (
        <>
            <ConfigProvider
                theme={{
                    token: {
                        colorPrimary: '#4FBE70',
                        colorLink: '#4FBE70',
                    }
                }}
            >
                <ProTable
                    size='small'
                    bordered={true}
                    scroll={{ x: 1300 }}
                    actionRef={actionRef}
                    dataSource={list}
                    columns={[ {
                        title: 'ID',
                        dataIndex: 'id',
                        width: 100,
                        search: false,
                    },
                        {
                            title: '投放标题',
                            dataIndex: 'title',
                            width: 240
                        },
                        {
                            title: '投放位置',
                            dataIndex: 'area_name',
                            search: false
                        },
                        {
                            title: '投放位置',
                            dataIndex: 'area_id',
                            hidden: true,
                            valueType: 'select',
                            renderFormItem: () => {
                                return (
                                    <ProFormSelect
                                        width='lg'
                                        fieldProps={{
                                            fieldNames: selectfieldAreaNames,
                                        }}
                                        request={async (keyword) =>
                                            GetAdvertareaList({ page: 1, pagesize: 100, keyword: keyword.keyWords }).then(res => {
                                                return res.data.advertareas;
                                            })
                                        }
                                        placeholder="请选择投放位置"
                                    />
                                )
                            }
                        },
                        {
                            title: '投放描述',
                            dataIndex: 'ad_description',
                            search: false
                        },
                        {
                            title: '企业',
                            dataIndex: 'company_name',
                            search: false
                        },
                        {
                            title: '企业',
                            dataIndex: 'company_id',
                            hidden: true,
                            valueType: 'select',
                            renderFormItem: () => {
                                return (
                                    <ProFormSelect
                                    showSearch
                                        fieldProps={{
                                            fieldNames: selectfieldNames,
                                        }}
                                        request={async (keyword) =>
                                            getCompanyList({ page: 1, pagesize: 100, keyword: keyword.keyWords }).then(res => {
                                                return res.data.list;
                                            })
                                        }
                                        placeholder="请选择企业"
                                    />
                                )
                            }
                        },
                        {
                            title: '投放状态',
                            dataIndex: 'hide_ad',
                            render: (_, record) => (<>
                                {
                                    <>
                                        {record.hide_ad === 0 && <Tag>未设置</Tag> }
                                        {record.hide_ad === 1 && <Tag>隐藏</Tag>}
                                        {record.hide_ad === 2 && <Tag color="green">显示</Tag> }
                                    </>
                                }

                            </>),
                             valueType: 'select',
                             valueEnum: {
                                 0: { text: '全部' },
                                 1: {
                                     text: '隐藏广告',
                                 },
                                 2: {
                                     text: '显示广告',
                                 }
                             },
                        },
                        {
                            title: '操作',
                            width: 300,
                            key: 'option',
                            valueType: 'option',
                            fixed: 'right',
                            render: (_, record, action) => [
                                <Button key='1' type='link' onClick={() => {
                                    setId(record.id)
                                    dispatch({ type: 'openModel/getOpenModal', payload: true })
                                }}>编辑</Button>,
                                <Popconfirm
                                    title="是否删除"
                                    onConfirm={(e) => {
                                        PostAdvertscheduleDel({ id: record.id }).then(res => {
                                            message.success('删除成功')
                                            actionRef.current.reload();
                                        })
                                    }}
                                    okText="删除"
                                    cancelText="取消"
                                >
                                    <a
                                        key="delete"
                                    >
                                        删除
                                    </a>
                                </Popconfirm>
                            ],
                        },
                    ]}
                    rowKey="id"
                    pagination={{
                        current: page,
                        pageSize: pageSize,
                        showSizeChanger: true,
                        total: total,
                        pageSizeOptions: [9, 18, 27, 99],
                        onChange(page, pageSize) {
                            setPage(page)
                            setPageSize(pageSize)
                        },
                        onShowSizeChange(current, size) {
                            setPage(current)
                            setPageSize(size)
                        }
                    }}
                    request={async (params = {} as Record<string, any>) =>
                        GetAdvertscheduleList({
                            page: page,
                            pagesize: pageSize,
                            sort: 'id',
                            sortby: 'desc',
                            keyword: params.title,
                            hide_ad:  params.hide_ad ? params.hide_ad : 0,
                            company_id: params.company_id,
                            area_id: params.area_id
                        }).then(res => {
                            setList(res.data.advertschedules)
                            setTotal(res.data.total)
                        })
                    }
                    headerTitle="广告位置列表"
                    toolBarRender={() => [
                        <Button type="primary" onClick={() => {
                            dispatch({ type: 'openModel/getOpenModal', payload: true })
                        }}>
                            投放广告
                        </Button>
                    ]}
                />
            </ConfigProvider>
        </>
    );
};


export default connect(({ openModel }: any) => ({
    openModel
}))(PagesMainAdvertisementPutinTable);
