import { useRef, useState, useEffect } from 'react';
import { connect, history } from '@umijs/max';
import type { ActionType, ProFormInstance } from '@ant-design/pro-components';
import {
    ProTable, TableDropdown
} from '@ant-design/pro-components';
import { Button, Image, ConfigProvider, Popconfirm, message,Tag } from 'antd';
import { listSection, delSection } from '@/apis/api';
import { Imageprefix } from '@/constants';

const PagesMainInformationSectionTable: React.FC = ({ dispatch, openModel, getId }: any) => {
    const actionRef = useRef<ActionType>();
    const [list, setList] = useState<object[]>([])
    const [total, setTotal] = useState<number>(0)
    const [page, setPage] = useState<number>(1)
    const [pageSize, setPageSize] = useState<number>(10)

    const setId = (id: number) => {
        getId(id)
    }

    useEffect(() => {
        if (!openModel.openModal) {
            actionRef.current.reload();
        }
    }, [openModel.openModal])

    return (
        <>
            <ConfigProvider
                theme={{
                    token: {
                        colorPrimary: '#4FBE70',
                        colorLink: '#4FBE70',
                    }
                }}
            >
                <ProTable
                    size='small'
                    bordered={true}
                    scroll={{ x: 1300 }}
                    actionRef={actionRef}
                    dataSource={list}
                    columns={[
                        {
                            title: 'ID',
                            dataIndex: 'id',
                            width: 100,
                            search: false,
                        },
                        {
                            title: '栏目名称',
                            dataIndex: 'name'
                        },
                        {
                            title: '栏目编码',
                            dataIndex: 'code'
                        },
                        {
                            title: '可见',
                            dataIndex: 'display',
                            search: false,
                            render: (_, record) => (<>
                                {
                                    <>
                                        {record.display === 1 ? <Tag color="green">可见</Tag> : <Tag>不可见</Tag>}
                                    </>
                                }

                            </>),
                        },
                        {
                            title: '封面图',
                            dataIndex: 'cover_img',
                            search: false,
                            render: (_, record) => (<>
                                <Image src={`${Imageprefix}${record.cover_img}`} width={40} height={40} />
                            </>
                            )
                        },
                        {
                            title: '描述',
                            dataIndex: 'description',
                            search: false
                        },
                        {
                            title: '操作',
                            width: 300,
                            key: 'option',
                            valueType: 'option',
                            fixed: 'right',
                            render: (_, record, action) => [
                                <Button key='1' type='link' onClick={() => {
                                    setId(record)
                                    dispatch({ type: 'openModel/getOpenModal', payload: true })
                                }}>编辑</Button>,
                                <Button key='1' type='link' onClick={() => {
                                    record.nextlevel = record.id // 添加下级栏目，把id赋值给nextlevel
                                    setId(record)
                                    dispatch({ type: 'openModel/getOpenModal', payload: true })
                                }}>添加下级栏目</Button>,
                                <Popconfirm
                                    title="是否删除"
                                    onConfirm={(e) => {
                                        delSection({ id: record.id }).then(res => {
                                            message.success('删除成功')
                                            actionRef.current.reload();
                                        })
                                    }}
                                    okText="删除"
                                    cancelText="取消"
                                >
                                    <a
                                        key="delete"
                                    >
                                        删除
                                    </a>
                                </Popconfirm>
                            ],
                        },
                    ]}
                    rowKey="id"
                    pagination={{
                        current: page,
                        pageSize: pageSize,
                        showSizeChanger: true,
                        total: total,
                        pageSizeOptions: [9, 18, 27, 99],
                        onChange(page, pageSize) {
                            setPage(page)
                            setPageSize(pageSize)
                        },
                        onShowSizeChange(current, size) {
                            setPage(current)
                            setPageSize(size)
                        }
                    }}
                    request={async (params = {} as Record<string, any>) =>
                        listSection({
                            page: page,
                            pagesize: pageSize,
                            sort: 'id',
                            sortby: 'desc',
                            keyword: params.name,

                        }).then(res => {
                            setList(res.data.sections)
                            setTotal(res.data.total)
                        })
                    }
                    headerTitle="栏目/频道"
                    toolBarRender={() => [
                        <Button type="primary" onClick={() => {
                            dispatch({ type: 'openModel/getOpenModal', payload: true })
                        }}>
                            添加栏目/频道
                        </Button>
                    ]}
                    expandable={{
                        childrenColumnName: 'childs', // 指定子节点数据的字段名
                    }}
                />
            </ConfigProvider>
        </>
    );
};


export default connect(({ openModel }: any) => ({
    openModel
}))(PagesMainInformationSectionTable);
